#[non_exhaustive]pub struct AuditEntry {
pub timestamp: String,
pub url: String,
pub method: String,
pub status: u16,
pub duration_ms: u64,
pub blocked: bool,
pub leak_detected: bool,
pub credential_injected: Option<String>,
}Expand description
A single audit log entry for a proxied request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timestamp: StringISO 8601 timestamp.
url: StringThe request URL (query parameter values are redacted when logged).
method: StringHTTP method.
status: u16Response status code.
duration_ms: u64Request duration in milliseconds.
blocked: boolWhether the request was blocked by the allowlist.
leak_detected: boolWhether a credential leak was detected.
credential_injected: Option<String>Domain for which a credential was injected, if any.
Implementations