Module credentials

Module credentials 

Credential injection at the network proxy boundary.

Credentials are injected into outbound requests based on the destination domain. The WASM guest and container never see raw API keys.

Structs

CredentialInjector
Maps destination domains to credential injection rules.
CredentialMapping
How to inject a credential into an outbound request.