#[non_exhaustive]pub struct CredentialMapping {
pub header: String,
pub value: Zeroizing<String>,
}Expand description
How to inject a credential into an outbound request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.header: StringHTTP header name to set.
value: Zeroizing<String>Header value (including any prefix like “Bearer “).
Wrapped in Zeroizing so the secret is cleared from memory on drop.